@@ -51,8 +51,8 @@ g_filename = __file__.split('/')[-1]
 g_module_name = g_filename
 if g_filename.rfind('.py') != -1:
     g_module_name = g_filename[:g_filename.rfind('.py')]
-g_date_str = '2022-8-24'
-g_version_str = '0.1.0'
+g_date_str = '2022-9-09'
+g_version_str = '0.2.1'
 g_program_name = g_filename
 #sys.stderr.write(g_program_name+' v'+g_version_str+' '+g_date_str+' ')
 
@@ -104,7 +104,7 @@ def IsFloat(s):
 
 def ExtractFFTableAB(lines,
                      num_atom_types,
-                     optional_section_name = '',
+                     allowed_section_names = None,
                      num_skip_lines = 0,
                      blanks_before_target = -1):
     count_blanks = 0
@@ -146,14 +146,14 @@ def ExtractFFTableAB(lines,
                     a = i
             else:
                 tokens = line.strip().split()
-                if optional_section_name and (optional_section_name != ''):
+                if allowed_section_names and len(allowed_section_names) > 0:
                     if ((len(tokens) == 1) and
-                        (not tokens[0] in optional_section_name)):
-                        raise InputError('Format Error: Expected "' +
-                                         optional_section_name +
-                                         '". Found "' +
+                        (not tokens[0] in allowed_section_names)):
+                        raise InputError('Format Error: Expected ' +
+                                         str(allowed_section_names) +
+                                         '. Found \'' +
                                          tokens[0]+
-                                         '". (Split file and use --bond, --angle, --dihedral, --improper arguments instead.)')
+                                         '\'. (Split file and use --bond, --angle, --dihedral, --improper arguments instead.)')
                 elif len(tokens) != 0:
                     raise InputError('Format Error: Unnexpected text: "' +
                                      line.strip() + '"')
@@ -167,22 +167,22 @@ def ExtractFFTableAB(lines,
 
 
 def ExtractMassTextAB(lines, num_skip_lines = 0):
-    return ExtractFFTableAB(lines, 1, ('MASS'), num_skip_lines)
+    return ExtractFFTableAB(lines, 1, ('MASS', 'MASSES'), num_skip_lines)
 
 def ExtractBondTextAB(lines, num_skip_lines = 0):
-    return ExtractFFTableAB(lines, 2, ('BOND'), num_skip_lines)
+    return ExtractFFTableAB(lines, 2, ('BOND', 'BONDS'), num_skip_lines)
 
 def ExtractAngleTextAB(lines, num_skip_lines = 0):
-    return ExtractFFTableAB(lines, 3, ('ANGL'), num_skip_lines)
+    return ExtractFFTableAB(lines, 3, ('ANGL', 'ANGLE', 'ANGLES'), num_skip_lines)
 
 def ExtractDihedralTextAB(lines, num_skip_lines = 0):
-    return ExtractFFTableAB(lines, 4, ('DIHE'), num_skip_lines)
+    return ExtractFFTableAB(lines, 4, ('DIHE', 'DIHEDRAL', 'DIHEDRALS', 'TOR', 'TORSION', 'TORSIONS'), num_skip_lines)
 
 def ExtractImproperTextAB(lines, num_skip_lines = 0):
-    return ExtractFFTableAB(lines, 4, ('IMPR'), num_skip_lines)
+    return ExtractFFTableAB(lines, 4, ('IMPR', 'IMPROPER', 'IMPROPERS'), num_skip_lines)
 
 def ExtractPairTextAB(lines, num_skip_lines = 0):
-    return ExtractFFTableAB(lines, 1, ('NONB', 'MOD4'), num_skip_lines)
+    return ExtractFFTableAB(lines, 1, ('NONB', 'NONBON', 'NONBOND', 'NONBONDED', 'MOD4'), num_skip_lines)
 
 
 
@@ -630,9 +630,11 @@ def ConvertImproper2Lt(lines_improper):
 
 
 
-def ConvertPair2Lt(lines_pair):
+def ConvertPair2Lt(lines_pair,
+                   lines_mass=[]):
     output_lines = []
     pair_style = 'lj/charmm/coul/long'
+    atom_types_in_pairs = set([])
     # NOTE: LAMMPS complains if you attempt to use lj/charmm/coul/long
     # on a system if it does not contain any charged particles.
     # Moltemplate does not assign atomic charge,
@@ -646,6 +648,7 @@ def ConvertPair2Lt(lines_pair):
         atype = atype.replace('*','star')
         #atype = atype.replace('X','*')
         assert(atype != 'X')
+        atom_types_in_pairs.add(atype)
         # UGGHHH
         # OLD CODE:
         #sig=tokens[1]
@@ -673,6 +676,17 @@ def ConvertPair2Lt(lines_pair):
         if len(comments.strip()) > 0:
             output_lines.append('   # '+comments)
         output_lines.append('\n')
+    # Any missing pair_coeffs (for atoms that are defined in the Masses section)
+    # should be supplied with default values (so that LAMMPS doesn't complain).
+    for i in range(0, len(lines_mass)):
+        line = lines_mass[i]
+        tokens= line.split()
+        atype = tokens[0]
+        if not (atype in atom_types_in_pairs):
+            eps = '0.0'
+            sig = '1.0'
+            output_lines.append('    pair_coeff @atom:'+atype+' @atom:'+atype+' '+pair_style+' '+eps+' '+sig+' # (default parameters)\n')
+            sys.stderr.write('WARNING: No Lennard-Jones parameters defined for atom type "'+atype+'" in source file.\n')
     output_lines.append('  } # (end of pair_coeffs)\n')
     return output_lines
 
@@ -696,7 +710,7 @@ def ConvertAmberSections2Lt(object_name,
     lines_angle_new      = ConvertAngle2Lt(lines_angle)
     lines_dihedral_new   = ConvertDihedral2Lt(lines_dihedral)
     lines_improper_new   = ConvertImproper2Lt(lines_improper)
-    lines_pair_new       = ConvertPair2Lt(lines_pair)
+    lines_pair_new       = ConvertPair2Lt(lines_pair, lines_mass)
 
     lines_prefix = []
     if object_name and object_name != "":
@@ -935,7 +949,7 @@ def main():
 # and a corresponding FRCMOD file (named "benzene.frcmod").  Use:
 #
 # mol22lt.py --in benzene.mol2 --out benzene.lt --name Benzene \\
-#            --ff MyForceField --ff my_force_field.lt
+#            --ff MyForceField --ff-file my_force_field.lt
 # amber2lt.py --in benzene.frcmod --name MyForceField >> my_force_field.lt
 #
 # ...The resulting "benzene.lt" file will have this format:
